@@ -14,7 +14,7 @@ static glp_prob *lp = NULL;
 
 // call destructor from the R level to guarantee that data has been
 // copied to R data structures.
-void Rglpk_delete_prob() {
+void Rglpk_delete_prob(void) {
   extern glp_prob *lp;
   // delete problem object (if any)
   if (lp){
@@ -212,7 +212,7 @@ void Rglpk_retrieve_MP_from_file (char **file, int *type,
   if ( status != 0 ) {
     glp_delete_prob(lp);
     lp = NULL;
-    error("Reading file %c failed.", *file);
+    error("Reading file %s failed.", *file);
   }
   
   if(*lp_verbosity==1)
